@@ -1,19 +1,19 @@
-/** 
+/**
  * XML Security Library (http://www.aleksey.com/xmlsec).
  *
  * Crypto engine selection.
  *
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
- * 
+ *
  * Copyright (C) 2002-2003 Aleksey Sanin <aleksey@aleksey.com>
  */
 #ifndef __XMLSEC_CRYPTO_H__
-#define __XMLSEC_CRYPTO_H__    
+#define __XMLSEC_CRYPTO_H__
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
 #include <xmlsec/xmlsec.h>
 
@@ -42,6 +42,7 @@ extern "C" {
 #ifdef XMLSEC_CRYPTO_MSCRYPTO
 #include <xmlsec/mscrypto/app.h>
 #include <xmlsec/mscrypto/crypto.h>
+#include <xmlsec/mscrypto/x509.h>
 #include <xmlsec/mscrypto/symbols.h>
 #else /* XMLSEC_CRYPTO_MSCRYPTO */
 #ifdef XMLSEC_CRYPTO_NSS
